@@ -2,6 +2,6 @@ from faker.factory import Factory
 from faker.generator import Generator
 from faker.proxy import Faker
 
-VERSION = '9.5.2'
+VERSION = "9.6.0"
 
-__all__ = ('Factory', 'Generator', 'Faker')
+__all__ = ("Factory", "Generator", "Faker")
