@@ -27,7 +27,7 @@ class TestJaJp:
 
     def test_phone_number(self, faker, num_samples):
         for _ in range(num_samples):
-            pattern: Pattern = re.compile(r'(?:0[789]0|\d{2})-\d{4}-\d{4}')
+            pattern: Pattern = re.compile(r"(?:0[789]0|\d{2})-\d{4}-\d{4}")
             phone_number = faker.phone_number()
             assert pattern.fullmatch(phone_number)
 
@@ -37,33 +37,28 @@ class TestPtBr:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'(?:\+55 )?'
-            r'(?:[1-8]1|84|\((?:0[1-8]1|084)\))'
-            r' \d{4}[ -]\d{4}|'
-            r'\d{4}?[ -]\d{3}[ -]\d{4}',
+            r"(?:\+55 )?" r"(?:[1-8]1|84|\((?:0[1-8]1|084)\))" r" \d{4}[ -]\d{4}|" r"\d{4}?[ -]\d{3}[ -]\d{4}",
         )
         for _ in range(num_samples):
             phone_number = faker.phone_number()
             assert pattern.fullmatch(phone_number)
 
     def test_msisdn(self, faker, num_samples):
-        pattern: Pattern = re.compile(r'55(?:[1-8]19|849)\d{8}')
+        pattern: Pattern = re.compile(r"55(?:[1-8]19|849)\d{8}")
         for _ in range(num_samples):
             msisdn = faker.msisdn()
             assert pattern.fullmatch(msisdn)
 
     def test_cellphone(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'(?:\+55 )?'
-            r'(?:\d{2}|\(0?\d{2}\))'
-            r' 9 ?\d{4}[ -]\d{4}',
+            r"(?:\+55 )?" r"(?:\d{2}|\(0?\d{2}\))" r" 9 ?\d{4}[ -]\d{4}",
         )
         for _ in range(num_samples):
             cellphone = faker.cellphone_number()
             assert pattern.fullmatch(cellphone)
 
     def test_service_phone(self, faker, num_samples):
-        pattern: Pattern = re.compile(r'1(?:0|2|5|8|9)?(?:[0-9])')
+        pattern: Pattern = re.compile(r"1(?:0|2|5|8|9)?(?:[0-9])")
         for _ in range(num_samples):
             service = faker.service_phone_number()
             assert pattern.fullmatch(service)
@@ -74,13 +69,7 @@ class TestHuHu:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'(?:'
-            r'\+36 \d{2} |'
-            r'\(06\)\d{2}/|'
-            r'\(\d{2}\)/|'
-            r'\d{2}/|'
-            r'06-\d{1,2}/'
-            r')\d{3}[- ]\d{4}',
+            r"(?:" r"\+36 \d{2} |" r"\(06\)\d{2}/|" r"\(\d{2}\)/|" r"\d{2}/|" r"06-\d{1,2}/" r")\d{3}[- ]\d{4}",
         )
         for _ in range(num_samples):
             phone_number = faker.phone_number()
@@ -94,11 +83,11 @@ class TestThTh:
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
             # leading zero or internaional code
-            r'((\+66)|\+66[ -]?\(0\)|0)[ -]?'
+            r"((\+66)|\+66[ -]?\(0\)|0)[ -]?"
             # landline or mobile
-            r'([23457][ -]?(\d[ -]?){6}\d|[689][ -]?(\d[ -]?){7}\d)'
+            r"([23457][ -]?(\d[ -]?){6}\d|[689][ -]?(\d[ -]?){7}\d)"
             # extension
-            r'([ ]?(x|ext|ต่อ)[\.]?[ ]?\d{1,5})?',
+            r"([ ]?(x|ext|ต่อ)[\.]?[ ]?\d{1,5})?",
             re.IGNORECASE,
         )
         for _ in range(num_samples):
@@ -112,8 +101,7 @@ class TestHyAm:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'(?:[23]\d{2}-|\([23]\d{2}\) |[23]\d{2}\.)\d{5}|'
-            r'(?:(?:10|9\d)-|\((?:10|9\d)\) |(?:10|9\d)\.)\d{6}',
+            r"(?:[23]\d{2}-|\([23]\d{2}\) |[23]\d{2}\.)\d{5}|" r"(?:(?:10|9\d)-|\((?:10|9\d)\) |(?:10|9\d)\.)\d{6}",
         )
         for _ in range(num_samples):
             phone_number = faker.phone_number()
@@ -126,9 +114,9 @@ class TestEnPh:
 
     @classmethod
     def setup_class(cls):
-        cls.mobile_number_pattern: Pattern = re.compile(r'^(?:0|\+63)(\d+)-\d{3}-\d{4}$')
-        cls.area2_landline_number_pattern: Pattern = re.compile(r'^(?:0|\+63)2-(\d{4})-\d{4}')
-        cls.non_area2_landline_number_pattern: Pattern = re.compile(r'^(?:0|\+63)(\d{2})-(\d{3})-\d{4}')
+        cls.mobile_number_pattern: Pattern = re.compile(r"^(?:0|\+63)(\d+)-\d{3}-\d{4}$")
+        cls.area2_landline_number_pattern: Pattern = re.compile(r"^(?:0|\+63)2-(\d{4})-\d{4}")
+        cls.non_area2_landline_number_pattern: Pattern = re.compile(r"^(?:0|\+63)(\d{2})-(\d{3})-\d{4}")
         cls.globe_mobile_number_prefixes = EnPhPhoneNumberProvider.globe_mobile_number_prefixes
         cls.smart_mobile_number_prefixes = EnPhPhoneNumberProvider.smart_mobile_number_prefixes
         cls.sun_mobile_number_prefixes = EnPhPhoneNumberProvider.sun_mobile_number_prefixes
@@ -167,13 +155,13 @@ class TestEnPh:
         for _ in range(num_samples):
             number = faker.globe_area2_landline_number()
             match = self.area2_landline_number_pattern.match(number)
-            assert match and match.group(1).startswith('7')
+            assert match and match.group(1).startswith("7")
 
     def test_pldt_area2_landline_number(self, faker, num_samples):
         for _ in range(num_samples):
             number = faker.pldt_area2_landline_number()
             match = self.area2_landline_number_pattern.match(number)
-            assert match and match.group(1).startswith('8')
+            assert match and match.group(1).startswith("8")
 
     def test_bayantel_area2_landline_number(self, faker, num_samples):
         for _ in range(num_samples):
@@ -191,12 +179,14 @@ class TestEnPh:
         for _ in range(num_samples):
             number = faker.area2_landline_number()
             match = self.area2_landline_number_pattern.match(number)
-            assert match and any([
-                match.group(1).startswith('7'),
-                match.group(1).startswith('8'),
-                match.group(1) in self.bayantel_landline_identifiers,
-                match.group(1) in self.misc_landline_identifiers,
-            ])
+            assert match and any(
+                [
+                    match.group(1).startswith("7"),
+                    match.group(1).startswith("8"),
+                    match.group(1) in self.bayantel_landline_identifiers,
+                    match.group(1) in self.misc_landline_identifiers,
+                ]
+            )
 
     def test_non_area2_landline_number(self, faker, num_samples):
         for _ in range(num_samples):
@@ -211,23 +201,27 @@ class TestEnPh:
             non_area2_match = self.non_area2_landline_number_pattern.match(number)
             assert area2_match or non_area2_match
             if area2_match:
-                assert any([
-                    area2_match.group(1).startswith('7'),
-                    area2_match.group(1).startswith('8'),
-                    area2_match.group(1) in self.bayantel_landline_identifiers,
-                    area2_match.group(1) in self.misc_landline_identifiers,
-                ])
+                assert any(
+                    [
+                        area2_match.group(1).startswith("7"),
+                        area2_match.group(1).startswith("8"),
+                        area2_match.group(1) in self.bayantel_landline_identifiers,
+                        area2_match.group(1) in self.misc_landline_identifiers,
+                    ]
+                )
             elif non_area2_match:
                 assert non_area2_match.group(1) in self.non_area2_landline_area_codes
 
 
 class TestFilPh(TestEnPh):
     """Test fil_PH phone number provider methods"""
+
     pass
 
 
 class TestTlPh(TestEnPh):
     """Test tl_PH phone number provider methods"""
+
     pass
 
 
@@ -236,8 +230,7 @@ class TestTaIn:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'\+91 \d{3} ?\d{7}|'
-            r'0\d{2}(-)?\d{2}(?(1)| ?)\d{6}',
+            r"\+91 \d{3} ?\d{7}|" r"0\d{2}(-)?\d{2}(?(1)| ?)\d{6}",
         )
         for _ in range(num_samples):
             phone_number = faker.phone_number()
@@ -249,8 +242,7 @@ class TestEsEs:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            r'\+34 ?(?:7[0-4]|[689]\d)\d'
-            r'(?: \d{3} \d{3}|\d{6}| \d{2} \d{2} \d{2})',
+            r"\+34 ?(?:7[0-4]|[689]\d)\d" r"(?: \d{3} \d{3}|\d{6}| \d{2} \d{2} \d{2})",
         )
         for _ in range(num_samples):
             phone_number = faker.phone_number()
@@ -260,22 +252,10 @@ class TestEsEs:
 class TestArAe:
     """Test ar_AE phone number provider methods"""
 
-    cellphone_pattern: str = (
-        r'(?:\+|00)971\s?5[024568]\s?\d{3}\s?\d{4}|'
-        r'05[024568]\s?\d{3}\s?\d{4}'
-    )
-    telephone_pattern: str = (
-        r'(?:\+|00)971\s?[1234679]\s?\d{3}\s?\d{4}|'
-        r'0[1234679]\s?\d{3}\s?\d{4}'
-    )
-    toll_pattern: str = (
-        r'200\d{4}|'
-        r'600\d{6}|'
-        r'800\d{3,7}'
-    )
-    service_phone_pattern: str = (
-        r'9(?:9(?:9|8|7|6|1)|01|22)'
-    )
+    cellphone_pattern: str = r"(?:\+|00)971\s?5[024568]\s?\d{3}\s?\d{4}|" r"05[024568]\s?\d{3}\s?\d{4}"
+    telephone_pattern: str = r"(?:\+|00)971\s?[1234679]\s?\d{3}\s?\d{4}|" r"0[1234679]\s?\d{3}\s?\d{4}"
+    toll_pattern: str = r"200\d{4}|" r"600\d{6}|" r"800\d{3,7}"
+    service_phone_pattern: str = r"9(?:9(?:9|8|7|6|1)|01|22)"
 
     def test_cellphone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(self.cellphone_pattern)
@@ -303,10 +283,10 @@ class TestArAe:
 
     def test_phone_number(self, faker, num_samples):
         pattern: Pattern = re.compile(
-            rf'{self.cellphone_pattern}|'
-            rf'{self.telephone_pattern}|'
-            rf'{self.toll_pattern}|'
-            rf'{self.service_phone_pattern}',
+            rf"{self.cellphone_pattern}|"
+            rf"{self.telephone_pattern}|"
+            rf"{self.toll_pattern}|"
+            rf"{self.service_phone_pattern}",
         )
         for _ in range(num_samples):
             phone = faker.phone_number()
